// --------------------------------------------------------------------------
//
// Media Feed Screen Saver
// http://blog.debin.net/Media-feed-screen-saver/
// damien@debin.net
//
// --------------------------------------------------------------------------
//
// Copyright (c) 2006 Damien Debin.
// All rights reserved.
// 
// This file is part of Media Feed Screen Saver.
// 
// Media Feed Screen Saver is free software; you can redistribute it
// and/or modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2 of
// the License, or (at your option) any later version.
// 
// Foobar is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with Foobar; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
// --------------------------------------------------------------------------

using System;
using System.Configuration;
using System.Drawing;
using System.Windows.Forms;
using MediaFeedScreenSaver.Rss;

namespace MediaFeedScreenSaver
{
    partial class OptionsForm : Form
    {
        public OptionsForm()
        {
            InitializeComponent();

            this.Text = "Media Feed Screen Saver Settings - v" + Program.VersionInfo;


            // Load the text boxes from the current settings
            try
            {
                rssFeedTextBox.Text = Properties.Settings.Default.RssFeedUri;
                showComboBox.SelectedIndex = Properties.Settings.Default.ShowTitles;
                bkgdColorLabel.BackColor = Properties.Settings.Default.BkgdColor;
                textColorLabel.BackColor = Properties.Settings.Default.TextColor;
                msecNumericUpDown.Value = Properties.Settings.Default.MsecBetweenPictures;
                feedRefreshNumericUpDown.Value = Properties.Settings.Default.FeedRefreshInterval;
                fadingCheckBox.Checked = Properties.Settings.Default.TitleFading;
                highQualityCheckBox.Checked = Properties.Settings.Default.HighQualityResizing;
            }
            catch
            {
                MessageBox.Show("There was a problem reading in the settings for your screen saver.");
            }
        }

        private void SaveChanges()
        {
            Properties.Settings.Default.RssFeedUri = rssFeedTextBox.Text;
            Properties.Settings.Default.ShowTitles = showComboBox.SelectedIndex;
            Properties.Settings.Default.BkgdColor = bkgdColorLabel.BackColor;
            Properties.Settings.Default.TextColor = textColorLabel.BackColor;
            Properties.Settings.Default.MsecBetweenPictures = (int)msecNumericUpDown.Value;
            Properties.Settings.Default.FeedRefreshInterval = (int)feedRefreshNumericUpDown.Value;
            Properties.Settings.Default.TitleFading = fadingCheckBox.Checked;
            Properties.Settings.Default.HighQualityResizing = highQualityCheckBox.Checked;
            Properties.Settings.Default.Save();
        }

        private void btnOK_Click(object sender, EventArgs e)
        {
            try
            {
                SaveChanges();
            }
            catch (ConfigurationException)
            {
                MessageBox.Show("Your settings couldn't be saved.  Make sure that you have a .config file in the same directory as your screensaver.", "Failed to Save Settings", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            finally
            {
                Close();
            }
        }

        private void btnCancel_Click(object sender, EventArgs e)
        {
            Close();
        }

        // Check whether the user provided URI points to a valid RSS feed
        private void validateButton_Click(object sender, EventArgs e)
        {
            try
            {
                RssFeed.FromUri(rssFeedTextBox.Text, Size.Empty);
            }
            catch
            {
                MessageBox.Show("Not a valid RSS feed.", "Not a valid RSS feed.", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }

            MessageBox.Show("Valid RSS feed.", "Valid RSS feed.", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
        }

        private void bkgdColorButton_Click(object sender, EventArgs e)
        {
            colorDialog1.ShowDialog();
            bkgdColorLabel.BackColor = colorDialog1.Color;
        }

        private void textColorButton_Click(object sender, EventArgs e)
        {
            colorDialog1.ShowDialog();
            textColorLabel.BackColor = colorDialog1.Color;
        }

        private void programUrlLinkLabel_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            try
            {
                //Call the Process.Start method to open the default browser with a URL
                System.Diagnostics.Process.Start(Program.ProgramURL);
            }
            catch
            {
                MessageBox.Show("Unable to open link that was clicked.");
            }
        }
    }
}